@@ -24,6 +24,8 @@ from socketdev.apitokens import ApiTokens
 from socketdev.auditlog import AuditLog
 from socketdev.analytics import Analytics
 from socketdev.alerttypes import AlertTypes
+from socketdev.basics import Basics
+from socketdev.uploadmanifests import UploadManifests
 from socketdev.log import log
 
 __author__ = "socket.dev"
@@ -72,6 +74,8 @@ class socketdev:
         self.auditlog = AuditLog(self.api)
         self.analytics = Analytics(self.api)
         self.alerttypes = AlertTypes(self.api)
+        self.basics = Basics(self.api)
+        self.uploadmanifests = UploadManifests(self.api)
 
     @staticmethod
     def set_timeout(timeout: int):
